@@ -6,82 +6,92 @@
     <message>
         <location filename="../mainwindow.cpp" line="10"/>
         <source>Copy</source>
-        <translation type="unfinished">نسخ</translation>
+        <translation>نسخ</translation>
     </message>
     <message>
         <location filename="../mainwindow.cpp" line="10"/>
         <source>Rename</source>
-        <translation type="unfinished">إعادة تسمية</translation>
+        <translation>إعادة تسمية</translation>
     </message>
     <message>
         <location filename="../mainwindow.cpp" line="10"/>
         <source>Move</source>
-        <translation type="unfinished">نقل</translation>
+        <translation>نقل</translation>
     </message>
     <message>
         <location filename="../mainwindow.cpp" line="10"/>
         <source>Delete</source>
-        <translation type="unfinished">حذف</translation>
+        <translation>حذف</translation>
     </message>
     <message>
         <location filename="../mainwindow.cpp" line="10"/>
         <source>Edit</source>
-        <translation type="unfinished">تحرير</translation>
+        <translation>تحرير</translation>
     </message>
     <message>
         <location filename="../mainwindow.cpp" line="10"/>
         <source>Share</source>
-        <translation type="unfinished">مشاركة</translation>
+        <translation>مشاركة</translation>
     </message>
     <message>
         <location filename="../mainwindow.cpp" line="10"/>
         <source>Compress</source>
-        <translation type="unfinished">أضغط</translation>
+        <translation>أضغط</translation>
     </message>
     <message>
         <location filename="../mainwindow.cpp" line="10"/>
         <source>Documents</source>
-        <translation type="unfinished">المستندات</translation>
+        <translation>المستندات</translation>
     </message>
     <message>
         <location filename="../mainwindow.cpp" line="10"/>
         <source>Images</source>
-        <translation type="unfinished">الصور</translation>
+        <translation>الصور</translation>
     </message>
     <message>
         <location filename="../mainwindow.cpp" line="10"/>
         <source>Camera</source>
-        <translation type="unfinished">الكاميرا</translation>
+        <translation>الكاميرا</translation>
     </message>
     <message>
         <location filename="../mainwindow.cpp" line="10"/>
         <source>Sounds</source>
-        <translation type="unfinished">الصوت</translation>
+        <translation>الصوت</translation>
     </message>
     <message>
         <location filename="../mainwindow.cpp" line="10"/>
         <source>Videos</source>
-        <translation type="unfinished">الفيديو</translation>
+        <translation>الفيديو</translation>
     </message>
     <message>
         <location filename="../mainwindow.cpp" line="10"/>
         <source>Added to Clipboard</source>
-        <translation type="unfinished">وأضاف إلى الحافظة</translation>
+        <translation>وأضاف إلى الحافظة</translation>
     </message>
     <message>
         <location filename="../mainwindow.cpp" line="10"/>
         <source>ERROR: Nothing selected to paste</source>
-        <translation type="unfinished">خطأ : لا شيء مختارة للصق</translation>
+        <translation>خطأ : لا شيء مختارة للصق</translation>
     </message>
     <message>
         <location filename="../error.cpp" line="10"/>
         <source>Not enough space to proceed.</source>
-        <translation type="unfinished">لايوجد مساحة كافية للمتابعة.</translation>
+        <translation>لايوجد مساحة كافية للمتابعة.</translation>
     </message>
     <message>
         <location filename="../error.cpp" line="10"/>
         <source>You don&apos;t have permissions to proceed.</source>
-        <translation type="unfinished">ليس لديك الصلاحيات للمتابعة.</translation>
+        <translation>ليس لديك الصلاحيات للمتابعة.</translation>
+    </message>
+    <message>
+        <location filename="../mainwindow.cpp" line="10"/>
+        <source>About</source>
+        <translation>عن البرنامج</translation>
+    </message>
+    <message>
+        <location filename="../mainwindow.cpp" line="10"/>
+        <source>Broken Symlink!</source>
+        <translation>الرابط ضعيف!</translation>
     </message>
 </context>
 <context>
@@ -89,7 +99,7 @@
     <message>
         <location filename="../bookwindow.cpp" line="10"/>
         <source>Bookmarks</source>
-        <translation type="unfinished">المفضلة</translation>
+        <translation>المفضلة</translation>
     </message>
 </context>
 <context>
@@ -97,12 +107,17 @@
     <message>
         <location filename="../home.cpp" line="10"/>
         <source>Home folder</source>
-        <translation type="unfinished">مسار البداية</translation>
+        <translation>مسار البداية</translation>
     </message>
     <message>
         <location filename="../home.cpp" line="10"/>
         <source>Compress destination</source>
-        <translation type="unfinished">مسار الضغط</translation>
+        <translation>مسار الضغط</translation>
+    </message>
+    <message>
+        <location filename="../home.cpp" line="10"/>
+        <source>Extract destination</source>
+        <translation>مسار فك الضغط</translation>
     </message>
 </context>
 <context>
@@ -110,7 +125,7 @@
     <message>
         <location filename="../clipboard.cpp" line="10"/>
         <source>Clipboard</source>
-        <translation type="unfinished">الحافظة</translation>
+        <translation>الحافظة</translation>
     </message>
 </context>
 <context>
@@ -118,12 +133,12 @@
     <message>
         <location filename="../bookmarks.cpp" line="10"/>
         <source>Bookmarks</source>
-        <translation type="unfinished">المفضلة</translation>
+        <translation>المفضلة</translation>
     </message>
     <message>
         <location filename="../bookmarks.cpp" line="10"/>
         <source>Delete</source>
-        <translation type="unfinished">حذف</translation>
+        <translation>حذف</translation>
     </message>
 </context>
 <context>
@@ -131,27 +146,32 @@
     <message>
         <location filename="../toolsdialog.cpp" line="10"/>
         <source>Tools</source>
-        <translation type="unfinished">الأدوات</translation>
+        <translation>الأدوات</translation>
     </message>
     <message>
         <location filename="../toolsdialog.cpp" line="10"/>
         <source>Add to Bookmarks</source>
-        <translation type="unfinished">أضافة الى المفضلة</translation>
+        <translation>أضافة الى المفضلة</translation>
     </message>
     <message>
         <location filename="../toolsdialog.cpp" line="10"/>
         <source>Create new folder</source>
-        <translation type="unfinished">إنشاء مجلد جديد</translation>
+        <translation>إنشاء مجلد جديد</translation>
     </message>
     <message>
         <location filename="../toolsdialog.cpp" line="10"/>
         <source>Create new document</source>
-        <translation type="unfinished">إنشاء مستند جديد</translation>
+        <translation>إنشاء مستند جديد</translation>
+    </message>
+    <message>
+        <location filename="../toolsdialog.cpp" line="10"/>
+        <source>Open terminal here</source>
+        <translation>فتح الترمنل هنا</translation>
     </message>
     <message>
         <location filename="../toolsdialog.cpp" line="10"/>
         <source>Sort</source>
-        <translation type="unfinished">ترتيب</translation>
+        <translation>ترتيب</translation>
     </message>
 </context>
 <context>
@@ -159,17 +179,17 @@
     <message>
         <location filename="../share.cpp" line="10"/>
         <source>Share</source>
-        <translation type="unfinished">مشاركة</translation>
+        <translation>مشاركة</translation>
     </message>
     <message>
         <location filename="../share.cpp" line="10"/>
         <source>Send via bluetooth</source>
-        <translation type="unfinished">أرسال بواسطة البلوتوث</translation>
+        <translation>أرسال بواسطة البلوتوث</translation>
     </message>
     <message>
         <location filename="../share.cpp" line="10"/>
         <source>Send via e-mail</source>
-        <translation type="unfinished">أرسال بواسطة الأيميل</translation>
+        <translation>أرسال بواسطة الأيميل</translation>
     </message>
 </context>
 <context>
@@ -177,122 +197,122 @@
     <message>
         <location filename="../qtcopydialog.cpp" line="10"/>
         <source>%1 of %2 completed</source>
-        <translation type="unfinished">%1 للأنهاء %2 و</translation>
+        <translation>1% للأنهاء %2 و</translation>
     </message>
     <message>
         <location filename="../qtcopydialog.cpp" line="10"/>
         <source>Warning</source>
-        <translation type="unfinished">تنبيه</translation>
+        <translation>تنبيه</translation>
     </message>
     <message>
         <location filename="../qtcopydialog.cpp" line="10"/>
         <source>Copy Warning</source>
-        <translation type="unfinished">تنبيه</translation>
+        <translation>تنبيه</translation>
     </message>
     <message>
         <location filename="../qtcopydialog.cpp" line="10"/>
         <source>Source doesn&apos;t exist.</source>
-        <translation type="unfinished">.لايوجد أي مصدر للملفات.</translation>
+        <translation>.لايوجد أي مصدر للملفات.</translation>
     </message>
     <message>
         <location filename="../qtcopydialog.cpp" line="10"/>
         <source>No enough space for copy the file.</source>
-        <translation type="unfinished">لايوجد مساحة كافية لنسخ الملف.</translation>
+        <translation>لايوجد مساحة كافية لنسخ الملف.</translation>
     </message>
     <message>
         <location filename="../qtcopydialog.cpp" line="10"/>
         <source>Source file is a directory. Omitting source directory.</source>
-        <translation type="unfinished">الملف المصدر مسار. تجاهل مصدر المسار.</translation>
+        <translation>الملف المصدر مسار. تجاهل مصدر المسار.</translation>
     </message>
     <message>
         <location filename="../qtcopydialog.cpp" line="10"/>
         <source>Source directory is a file. Omitting source file.</source>
-        <translation type="unfinished">المصدر مجلد لملف. تجاهل مصدر الملف.</translation>
+        <translation>المصدر مجلد لملف. تجاهل مصدر الملف.</translation>
     </message>
     <message>
         <location filename="../qtcopydialog.cpp" line="10"/>
         <source>Path to destination does not exist.</source>
-        <translation type="unfinished">مسار الملف غير موجود.</translation>
+        <translation>مسار الملف غير موجود.</translation>
     </message>
     <message>
         <location filename="../qtcopydialog.cpp" line="10"/>
         <source>Cannot create destination directory.</source>
-        <translation type="unfinished">لايمكن أنشاء المسار مباشرة.</translation>
+        <translation>لايمكن أنشاء المسار مباشرة.</translation>
     </message>
     <message>
         <location filename="../qtcopydialog.cpp" line="10"/>
         <source>Cannot open source file. Please check permissions.</source>
-        <translation type="unfinished"> لايمكن فتح الملف المصدر. تأكد من الصلاحيات. </translation>
+        <translation> لايمكن فتح الملف المصدر. تأكد من الصلاحيات. </translation>
     </message>
     <message>
         <location filename="../qtcopydialog.cpp" line="10"/>
         <source>Cannot open destination file. Please check permissions.</source>
-        <translation type="unfinished">لايمكن فتح مسار الملف . تأكد من الصلاحيات.</translation>
+        <translation>لايمكن فتح مسار الملف . تأكد من الصلاحيات.</translation>
     </message>
     <message>
         <location filename="../qtcopydialog.cpp" line="10"/>
         <source>Force: Cannot remove destination file.</source>
-        <translation type="unfinished">لايمكن حذف مسار الملف.</translation>
+        <translation>لايمكن حذف مسار الملف.</translation>
     </message>
     <message>
         <location filename="../qtcopydialog.cpp" line="10"/>
         <source>Cannot create symbolic link targeting to source.</source>
-        <translation type="unfinished">لايمكن أنشاء وصلة لرابط المصدر.</translation>
+        <translation>لايمكن أنشاء وصلة لرابط المصدر.</translation>
     </message>
     <message>
         <location filename="../qtcopydialog.cpp" line="10"/>
         <source>Cannot read source file.</source>
-        <translation type="unfinished">لايمكن قراءة الملف المصدر.</translation>
+        <translation>لايمكن قراءة الملف المصدر.</translation>
     </message>
     <message>
         <location filename="../qtcopydialog.cpp" line="10"/>
         <source>Cannot write destination file.</source>
-        <translation type="unfinished">لايمكن الكتابة على مسار الملف.</translation>
+        <translation>لايمكن الكتابة على مسار الملف.</translation>
     </message>
     <message>
         <location filename="../qtcopydialog.cpp" line="10"/>
         <source>Cannot remove source.</source>
-        <translation type="unfinished">لايمكن حذف المصدر.</translation>
+        <translation>لايمكن حذف المصدر.</translation>
     </message>
     <message>
         <location filename="../qtcopydialog.cpp" line="10"/>
         <source>100% of %1 (Done)</source>
-        <translation type="unfinished">100% of %1 (Done)</translation>
+        <translation>100% of %1 (Done)</translation>
     </message>
     <message>
         <location filename="../qtcopydialog.cpp" line="10"/>
         <source>Copying...</source>
-        <translation type="unfinished">...جاري النسخ </translation>
+        <translation>...جاري النسخ </translation>
     </message>
     <message>
         <location filename="../qtcopydialog.cpp" line="10"/>
         <source>%1% of %2 (%3)</source>
-        <translation type="unfinished">%1% of %2 (%3)</translation>
+        <translation>%1 of %2 (%3)</translation>
     </message>
     <message>
         <location filename="../qtcopydialog.cpp" line="10"/>
         <source>Done</source>
-        <translation type="unfinished">إنهاء</translation>
+        <translation>إنهاء</translation>
     </message>
     <message>
         <location filename="../qtcopydialog.cpp" line="10"/>
         <source>Source</source>
-        <translation type="unfinished">المصدر</translation>
+        <translation>المصدر</translation>
     </message>
     <message>
         <location filename="../qtcopydialog.cpp" line="10"/>
         <source>Destination</source>
-        <translation type="unfinished">المسار</translation>
+        <translation>المسار</translation>
     </message>
     <message>
         <location filename="../qtcopydialog.cpp" line="10"/>
         <source>Cancel</source>
-        <translation type="unfinished">إلغاء</translation>
+        <translation>إلغاء</translation>
     </message>
     <message>
         <location filename="../qtcopydialog.cpp" line="10"/>
         <source>Close</source>
-        <translation type="unfinished">أغلاق</translation>
+        <translation>أغلاق</translation>
     </message>
 </context>
 <context>
@@ -300,37 +320,37 @@
     <message>
         <location filename="../qtcopydialog.cpp" line="10"/>
         <source>Copy Warning</source>
-        <translation type="unfinished">تنبيه</translation>
+        <translation>تنبيه</translation>
     </message>
     <message>
         <location filename="../qtcopydialog.cpp" line="10"/>
         <source>Source</source>
-        <translation type="unfinished">المصدر</translation>
+        <translation>المصدر</translation>
     </message>
     <message>
         <location filename="../qtcopydialog.cpp" line="10"/>
         <source>Destination</source>
-        <translation type="unfinished">المسار</translation>
+        <translation>المسار</translation>
     </message>
     <message>
         <location filename="../qtcopydialog.cpp" line="10"/>
         <source>Skip</source>
-        <translation type="unfinished">تجاهل</translation>
+        <translation>تجاهل</translation>
     </message>
     <message>
         <location filename="../qtcopydialog.cpp" line="10"/>
         <source>Overwrite</source>
-        <translation type="unfinished">إعادة كتابة</translation>
+        <translation>إعادة كتابة</translation>
     </message>
     <message>
         <location filename="../qtcopydialog.cpp" line="10"/>
         <source>Cancel</source>
-        <translation type="unfinished">إلغاء</translation>
+        <translation>إلغاء</translation>
     </message>
     <message>
         <location filename="../qtcopydialog.cpp" line="10"/>
         <source>Destination already exists.</source>
-        <translation type="unfinished">المسار موجود بالفعل.</translation>
+        <translation>المسار موجود بالفعل.</translation>
     </message>
 </context>
 <context>
@@ -338,37 +358,37 @@
     <message>
         <location filename="../deletedialog.cpp" line="10"/>
         <source>Preparing to delete %1 files</source>
-        <translation type="unfinished">التحضير للحذف %1 الملفات</translation>
+        <translation>التحضير للحذف %1 الملفات</translation>
     </message>
     <message>
         <location filename="../deletedialog.cpp" line="10"/>
         <source>Deleting %1</source>
-        <translation type="unfinished">حذف %1</translation>
+        <translation>حذف %1</translation>
     </message>
     <message>
         <location filename="../deletedialog.cpp" line="10"/>
         <source>Error deleting %1</source>
-        <translation type="unfinished">خطأ بالحذف %1</translation>
+        <translation>خطأ بالحذف %1</translation>
     </message>
     <message>
         <location filename="../deletedialog.cpp" line="10"/>
         <source>Delete Finished Ok</source>
-        <translation type="unfinished">تم الحذف بنجاح</translation>
+        <translation>تم الحذف بنجاح</translation>
     </message>
     <message>
         <location filename="../deletedialog.cpp" line="10"/>
         <source>Abort</source>
-        <translation type="unfinished">تجاهل</translation>
+        <translation>تجاهل</translation>
     </message>
     <message>
         <location filename="../deletedialog.cpp" line="10"/>
         <source>Close</source>
-        <translation type="unfinished">أغلاق</translation>
+        <translation>أغلاق</translation>
     </message>
     <message>
         <location filename="../deletedialog.cpp" line="10"/>
         <source>Deleting files</source>
-        <translation type="unfinished">حذف الملفات</translation>
+        <translation>حذف الملفات</translation>
     </message>
 </context>
 <context>
@@ -376,62 +396,87 @@
     <message>
         <location filename="../settings.cpp" line="10"/>
         <source>Settings</source>
-        <translation type="unfinished">الإعدادات</translation>
+        <translation>الإعدادات</translation>
     </message>
     <message>
         <location filename="../settings.cpp" line="10"/>
         <source>Apply</source>
-        <translation type="unfinished">تطبيق</translation>
+        <translation>تطبيق</translation>
     </message>
     <message>
         <location filename="../settings.cpp" line="10"/>
         <source>Cancel</source>
-        <translation type="unfinished">إلغاء</translation>
+        <translation>إلغاء</translation>
     </message>
     <message>
         <location filename="../settings.cpp" line="10"/>
         <source>Home folder</source>
-        <translation type="unfinished">مسار البداية</translation>
+        <translation>مسار البداية</translation>
     </message>
     <message>
         <location filename="../settings.cpp" line="10"/>
         <source>Icons Style</source>
-        <translation type="unfinished">أشكال الرموز</translation>
+        <translation>أشكال الرموز</translation>
     </message>
     <message>
         <location filename="../settings.cpp" line="10"/>
         <source>Text Editor</source>
-        <translation type="unfinished">محرر النصوص</translation>
+        <translation>محرر النصوص</translation>
     </message>
     <message>
         <location filename="../settings.cpp" line="10"/>
         <source>Enable root access (restart needed)</source>
-        <translation type="unfinished">تفعيل الصلاحيات لتعديل</translation>
+        <translation>تفعيل الصلاحيات لتعديل</translation>
     </message>
     <message>
         <location filename="../settings.cpp" line="10"/>
         <source>Show hidden files and folders</source>
-        <translation type="unfinished">مشاهدة الملفات والمجلدات المخفية</translation>
+        <translation>مشاهدة الملفات والمجلدات المخفية</translation>
     </message>
     <message>
         <location filename="../settings.cpp" line="10"/>
         <source>Show thumbnails for images</source>
-        <translation type="unfinished"> عرض الصور مصغرة</translation>
+        <translation> عرض الصور مصغرة</translation>
     </message>
     <message>
         <location filename="../settings.cpp" line="10"/>
         <source>Show details for files</source>
-        <translation type="unfinished">عرض تفاصيل عن الملفات</translation>
+        <translation>عرض تفاصيل عن الملفات</translation>
     </message>
     <message>
         <location filename="../settings.cpp" line="10"/>
         <source>Delete items from clipboard on Paste</source>
-        <translation type="unfinished">حذف البيانات من حافظة اللصق</translation>
+        <translation>حذف البيانات من حافظة اللصق</translation>
     </message>
     <message>
         <location filename="../settings.cpp" line="10"/>
         <source>Enable multiselection</source>
-        <translation type="unfinished">تفعيل التحديد المتعدد</translation>
+        <translation>تفعيل التحديد المتعدد</translation>
+    </message>
+    <message>
+        <location filename="../settings.cpp" line="10"/>
+        <source>Auto select items in clipboard</source>
+        <translation>الأختار التلقائي للعناصر من حافظة اللصق</translation>
+    </message>
+    <message>
+        <location filename="../settings.cpp" line="10"/>
+        <source>Orientation</source>
+        <translation>التدوير</translation>
+    </message>
+    <message>
+        <location filename="../settings.cpp" line="10"/>
+        <source>Automatic</source>
+        <translation>تلقائي</translation>
+    </message>
+    <message>
+        <location filename="../settings.cpp" line="10"/>
+        <source>Portrait</source>
+        <translation>عامودي</translation>
+    </message>
+    <message>
+        <location filename="../settings.cpp" line="10"/>
+        <source>Landscape</source>
+        <translation>أفقي</translation>
     </message>
 </context>
 <context>
@@ -439,27 +484,27 @@
     <message>
         <location filename="../newfolder.cpp" line="10"/>
         <source>Create folder</source>
-        <translation type="unfinished">إنشاء مجلد</translation>
+        <translation>إنشاء مجلد</translation>
     </message>
     <message>
         <location filename="../newfolder.cpp" line="10"/>
         <source>Enter new folder name</source>
-        <translation type="unfinished">ضع أسم للمجلد الجديد</translation>
+        <translation>ضع أسم للمجلد الجديد</translation>
     </message>
     <message>
         <location filename="../newfolder.cpp" line="10"/>
         <source>Cancel</source>
-        <translation type="unfinished">إلغاء</translation>
+        <translation>إلغاء</translation>
     </message>
     <message>
         <location filename="../newfolder.cpp" line="10"/>
         <source>Accept</source>
-        <translation type="unfinished">تطبيق</translation>
+        <translation>تطبيق</translation>
     </message>
     <message>
         <location filename="../newfolder.cpp" line="10"/>
         <source>Cannot create folder. Try another name.</source>
-        <translation type="unfinished">لايمكن أنشاء المجلد. حاول بأسم أخر.</translation>
+        <translation>لايمكن أنشاء المجلد. حاول بأسم أخر.</translation>
     </message>
 </context>
 <context>
@@ -467,27 +512,27 @@
     <message>
         <location filename="../qtcopydialog.cpp" line="10"/>
         <source>Retry</source>
-        <translation type="unfinished">إعادة</translation>
+        <translation>إعادة</translation>
     </message>
     <message>
         <location filename="../qtcopydialog.cpp" line="10"/>
         <source>Cancel</source>
-        <translation type="unfinished">إلغاء</translation>
+        <translation>إلغاء</translation>
     </message>
     <message>
         <location filename="../qtcopydialog.cpp" line="10"/>
         <source>Skip</source>
-        <translation type="unfinished">تجاهل</translation>
+        <translation>تجاهل</translation>
     </message>
     <message>
         <location filename="../qtcopydialog.cpp" line="10"/>
         <source>Source</source>
-        <translation type="unfinished">المصدر</translation>
+        <translation>المصدر</translation>
     </message>
     <message>
         <location filename="../newfolder.cpp" line="10"/>
         <source>Destination</source>
-        <translation type="unfinished">المسار</translation>
+        <translation>المسار</translation>
     </message>
 </context>
 <context>
@@ -495,27 +540,27 @@
     <message>
         <location filename="../rename.cpp" line="10"/>
         <source>Renaming</source>
-        <translation type="unfinished">إعادة التسمية</translation>
+        <translation>إعادة التسمية</translation>
     </message>
     <message>
         <location filename="../rename.cpp" line="10"/>
         <source>Enter new name</source>
-        <translation type="unfinished">أدخل الأسم الجديد</translation>
+        <translation>أدخل الأسم الجديد</translation>
     </message>
     <message>
         <location filename="../rename.cpp" line="10"/>
         <source>Accept</source>
-        <translation type="unfinished">تطبيق</translation>
+        <translation>تطبيق</translation>
     </message>
     <message>
         <location filename="../rename.cpp" line="10"/>
         <source>Cancel</source>
-        <translation type="unfinished">إلغاء</translation>
+        <translation>إلغاء</translation>
     </message>
     <message>
         <location filename="../rename.cpp" line="10"/>
         <source>Cannot rename. Try another name.</source>
-        <translation type="unfinished">لايمكن إعادة التسمة . حاول بأسم آخر.</translation>
+        <translation>لايمكن إعادة التسمة . حاول بأسم آخر.</translation>
     </message>
 </context>
 <context>
@@ -523,27 +568,27 @@
     <message>
         <location filename="../askdialog.cpp" line="10"/>
         <source>Deleting</source>
-        <translation type="unfinished">حذف</translation>
+        <translation>حذف</translation>
     </message>
     <message>
         <location filename="../askdialog.cpp" line="10"/>
         <source>Are you sure you want to delete %1?</source>
-        <translation type="unfinished">هل أنت متأكد من الحذف %1؟</translation>
+        <translation>هل أنت متأكد من الحذف %1؟</translation>
     </message>
     <message>
         <location filename="../askdialog.cpp" line="10"/>
         <source>Are you sure you want to delete selected files?</source>
-        <translation type="unfinished">هل أنت متأكد من حذف العناصر المحدد؟</translation>
+        <translation>هل أنت متأكد من حذف العناصر المحدد؟</translation>
     </message>
     <message>
         <location filename="../askdialog.cpp" line="10"/>
         <source>Yes</source>
-        <translation type="unfinished">نعم</translation>
+        <translation>نعم</translation>
     </message>
     <message>
         <location filename="../askdialog.cpp" line="10"/>
         <source>No</source>
-        <translation type="unfinished">لا</translation>
+        <translation>لا</translation>
     </message>
 </context>
 <context>
@@ -551,37 +596,47 @@
     <message>
         <location filename="../sort.cpp" line="10"/>
         <source>Sort</source>
-        <translation type="unfinished">الترتيب</translation>
+        <translation>الترتيب</translation>
+    </message>
+    <message>
+        <location filename="../sort.cpp" line="10"/>
+        <source>Ascending</source>
+        <translation>تصاعدي</translation>
+    </message>
+    <message>
+        <location filename="../sort.cpp" line="10"/>
+        <source>Descending</source>
+        <translation>تنازلي</translation>
     </message>
     <message>
         <location filename="../sort.cpp" line="10"/>
         <source>Name (A-Z)</source>
-        <translation type="unfinished">الأسم أ-ي</translation>
+        <translation>الأسم أ-ي</translation>
     </message>
     <message>
         <location filename="../sort.cpp" line="10"/>
         <source>Name (Z-A)</source>
-        <translation type="unfinished">الأسم ي-أ</translation>
+        <translation>الأسم ي-أ</translation>
     </message>
     <message>
         <location filename="../sort.cpp" line="10"/>
         <source>Date (olders first)</source>
-        <translation type="unfinished">التاريخ الأقدم أولاً</translation>
+        <translation>التاريخ الأقدم أولاً</translation>
     </message>
     <message>
         <location filename="../sort.cpp" line="10"/>
         <source>Date (recents first)</source>
-        <translation type="unfinished">التاريخ الأحدث أولاً</translation>
+        <translation>التاريخ الأحدث أولاً</translation>
     </message>
     <message>
         <location filename="../sort.cpp" line="10"/>
         <source>Size (smallers first)</source>
-        <translation type="unfinished">الحجم الأصغر أولاً</translation>
+        <translation>الحجم الأصغر أولاً</translation>
     </message>
     <message>
         <location filename="../sort.cpp" line="10"/>
         <source>Size (biggers first)</source>
-        <translation type="unfinished">الحجم الأكبر أولاً</translation>
+        <translation>الحجم الأكبر أولاً</translation>
     </message>
 </context>
 <context>
@@ -589,37 +644,37 @@
     <message>
         <location filename="../newdoc.cpp" line="10"/>
         <source>New document</source>
-        <translation type="unfinished">مستند جديد</translation>
+        <translation>مستند جديد</translation>
     </message>
     <message>
         <location filename="../newdoc.cpp" line="10"/>
         <source>Create</source>
-        <translation type="unfinished">إنشاء</translation>
+        <translation>إنشاء</translation>
     </message>
     <message>
         <location filename="../newdoc.cpp" line="10"/>
         <source>Cancel</source>
-        <translation type="unfinished">إلغاء</translation>
+        <translation>إلغاء</translation>
     </message>
     <message>
         <location filename="../newdoc.cpp" line="10"/>
         <source>Enter name for new document</source>
-        <translation type="unfinished">أدخل الأسم الجديد للمستند</translation>
+        <translation>أدخل الأسم الجديد للمستند</translation>
     </message>
     <message>
         <location filename="../newdoc.cpp" line="10"/>
         <source>Enter a valid file name</source>
-        <translation type="unfinished">أدخل أسم صحيح للملف</translation>
+        <translation>أدخل أسم صحيح للملف</translation>
     </message>
     <message>
         <location filename="../newdoc.cpp" line="10"/>
         <source>The file already exists. Try another name</source>
-        <translation type="unfinished">الملف موجود بالفعل. حاول بأسم آخر</translation>
+        <translation>الملف موجود بالفعل. حاول بأسم آخر</translation>
     </message>
     <message>
         <location filename="../newdoc.cpp" line="10"/>
         <source>Cannot create the file. Check permissions</source>
-        <translation type="unfinished">لايمكن إنشاء الملف. تأكد من الصلاحيات</translation>
+        <translation>لايمكن إنشاء الملف. تأكد من الصلاحيات</translation>
     </message>
 </context>
 <context>
@@ -627,12 +682,12 @@
     <message>
         <location filename="../error.cpp" line="10"/>
         <source>Error</source>
-        <translation type="unfinished">خطأ</translation>
+        <translation>خطأ</translation>
     </message>
     <message>
         <location filename="../error.cpp" line="10"/>
         <source>Accept</source>
-        <translation type="unfinished">تطبيق</translation>
+        <translation>تطبيق</translation>
     </message>
 </context>
 <context>
@@ -640,47 +695,47 @@
     <message>
         <location filename="../compressdlg.cpp" line="10"/>
         <source>Compress</source>
-        <translation type="unfinished">ضغط</translation>
+        <translation>ضغط</translation>
     </message>
     <message>
         <location filename="../compressdlg.cpp" line="10"/>
         <source>File name</source>
-        <translation type="unfinished">أسم الملف</translation>
+        <translation>أسم الملف</translation>
     </message>
     <message>
         <location filename="../compressdlg.cpp" line="10"/>
         <source>Compression</source>
-        <translation type="unfinished">طريقة الضغط</translation>
+        <translation>طريقة الضغط</translation>
     </message>
     <message>
         <location filename="../compressdlg.cpp" line="10"/>
         <source>Destination folder</source>
-        <translation type="unfinished">مسار المجلد</translation>
+        <translation>مسار المجلد</translation>
     </message>
     <message>
         <location filename="../compressdlg.cpp" line="10"/>
         <source>Accept</source>
-        <translation type="unfinished">تطبيق</translation>
+        <translation>تطبيق</translation>
     </message>
     <message>
         <location filename="../compressdlg.cpp" line="10"/>
         <source>Cancel</source>
-        <translation type="unfinished">إلغاء</translation>
+        <translation>إلغاء</translation>
     </message>
     <message>
         <location filename="../compressdlg.cpp" line="10"/>
         <source>The file already exists. Try another name.</source>
-        <translation type="unfinished">الملف موجود بالفعل. حاول بأسم آخر.</translation>
+        <translation>الملف موجود بالفعل. حاول بأسم آخر.</translation>
     </message>
     <message>
         <location filename="../compressdlg.cpp" line="10"/>
         <source>Not enough space to proceed.</source>
-        <translation type="unfinished">لايوجد مساحة كافية للمتابعة.</translation>
+        <translation>لايوجد مساحة كافية للمتابعة.</translation>
     </message>
     <message>
         <location filename="../compressdlg.cpp" line="10"/>
         <source>You don&apos;t have permissions to proceed.</source>
-        <translation type="unfinished">لاتمتلك الصلاحيات للمتابعة.</translation>
+        <translation>لاتمتلك الصلاحيات للمتابعة.</translation>
     </message>
 </context>
 <context>
@@ -688,27 +743,119 @@
     <message>
         <location filename="../compress.cpp" line="10"/>
         <source>Compressing</source>
-        <translation type="unfinished">ضغط</translation>
+        <translation>ضغط</translation>
     </message>
     <message>
         <location filename="../compress.cpp" line="10"/>
         <source>Adding %1...</source>
-        <translation type="unfinished">أضافة %1...</translation>
+        <translation>أضافة %1...</translation>
     </message>
     <message>
         <location filename="../compress.cpp" line="10"/>
         <source>Operation finished.</source>
-        <translation type="unfinished">تمت العملية بنجاح.</translation>
+        <translation>تمت العملية بنجاح.</translation>
     </message>
     <message>
         <location filename="../compress.cpp" line="10"/>
         <source>Cancel</source>
-        <translation type="unfinished">إلغاء</translation>
+        <translation>إلغاء</translation>
     </message>
     <message>
         <location filename="../compress.cpp" line="10"/>
         <source>Close</source>
-        <translation type="unfinished">أغلاق</translation>
+        <translation>أغلاق</translation>
+    </message>
+</context>
+<context>
+    <name>Unzip</name>
+    <message>
+        <location filename="../unzip.cpp" line="10"/>
+        <source>Extract files</source>
+        <translation>فك ضغط الملف</translation>
+    </message>
+    <message>
+        <location filename="../unzip.cpp" line="10"/>
+        <source>Cancel</source>
+        <translation>إلغاء</translation>
+    </message>
+    <message>
+        <location filename="../unzip.cpp" line="10"/>
+        <source>Not enough space to proceed.</source>
+        <translation>لاتمتلك مساحة كافية للمتابعة.</translation>
+    </message>
+    <message>
+        <location filename="../unzip.cpp" line="10"/>
+        <source>You don&apos;t have permissions to proceed.</source>
+        <translation>لاتمتلك الصلاحيات للمتابعة.</translation>
+    </message>
+</context>
+<context>
+    <name>UnzipDlg</name>
+    <message>
+        <location filename="../unzipdlg.cpp" line="10"/>
+        <source>Extract</source>
+        <translation>فك الضغط</translation>
+    </message>
+    <message>
+        <location filename="../unzipdlg.cpp" line="10"/>
+        <source>Destination folder</source>
+        <translation>مسار المجلد</translation>
+    </message>
+    <message>
+        <location filename="../unzipdlg.cpp" line="10"/>
+        <source>Keep existing files</source>
+        <translation>أبقاء الملفات الموجودة</translation>
+    </message>
+    <message>
+        <location filename="../unzipdlg.cpp" line="10"/>
+        <source>Accept</source>
+        <translation>تطبيق</translation>
+    </message>
+    <message>
+        <location filename="../unzipdlg.cpp" line="10"/>
+        <source>Cancel</source>
+        <translation>إلغاء</translation>
+    </message>
+</context>
+<context>
+    <name>Extract</name>
+    <message>
+        <location filename="../extract.cpp" line="10"/>
+        <source>Extracting</source>
+        <translation>فك الضغط</translation>
+    </message>
+    <message>
+        <location filename="../extract.cpp" line="10"/>
+        <source>Extracting %1...</source>
+        <translation>إستخراج %1...</translation>
+    </message>
+    <message>
+        <location filename="../extract.cpp" line="10"/>
+        <source>Operation finished.</source>
+        <translation>تمت العملية بنجاح.</translation>
+    </message>
+    <message>
+        <location filename="../extract.cpp" line="10"/>
+        <source>Cancel</source>
+        <translation>إلغاء</translation>
+    </message>
+    <message>
+        <location filename="../extract.cpp" line="10"/>
+        <source>Close</source>
+        <translation>إغلاق</translation>
+    </message>
+</context>
+<context>
+    <name>About</name>
+    <message>
+        <location filename="../about.cpp" line="10"/>
+        <source>About FileBox</source>
+        <translation>عن البرنامج</translation>
+    </message>
+    <message>
+        <location filename="../about.cpp" line="10"/>
+        <source>File Manager for Maemo 5</source>
+        <translation>مدير الملفات لميمو 5</translation>
     </message>
 </context>
 </TS>
