@@ -21,8 +21,7 @@
     <message>
         <location filename="../mainwindow.cpp" line="10"/>
         <source>Delete</source>
-        <translation>Supprimer
-</translation>
+        <translation>Supprimer</translation>
     </message>
     <message>
         <location filename="../mainwindow.cpp" line="10"/>
@@ -89,6 +88,11 @@
         <source>About</source>
         <translation>A propos de</translation>
     </message>
+    <message>
+        <location filename="../mainwindow.cpp" line="10"/>
+        <source>Broken Symlink!</source>
+        <translation>lien symbolique cassé!</translation>
+    </message>
 </context>
 <context>
     <name>BookWindow</name>
@@ -159,6 +163,11 @@
         <source>Create new document</source>
         <translation>Créer un nouveau document</translation>
     </message>
+    <message>
+        <location filename="../toolsdialog.cpp" line="10"/>
+        <source>Open terminal here</source>
+        <translation>Ouvrir un terminal ici</translation>
+    </message>
     <message>
         <location filename="../toolsdialog.cpp" line="10"/>
         <source>Sort</source>
@@ -444,6 +453,31 @@
         <source>Enable multiselection</source>
         <translation>Activer la multiselection</translation>
     </message>
+    <message>
+        <location filename="../settings.cpp" line="10"/>
+        <source>Auto select items in clipboard</source>
+        <translation>Sélection automatique des éléments du Presse-papiers</translation>
+    </message>
+    <message>
+        <location filename="../settings.cpp" line="10"/>
+        <source>Orientation</source>
+        <translation>Orientation</translation>
+    </message>
+    <message>
+        <location filename="../settings.cpp" line="10"/>
+        <source>Automatic</source>
+        <translation>Automatique</translation>
+    </message>
+    <message>
+        <location filename="../settings.cpp" line="10"/>
+        <source>Portrait</source>
+        <translation>Portrait</translation>
+    </message>
+    <message>
+        <location filename="../settings.cpp" line="10"/>
+        <source>Landscape</source>
+        <translation>Paysage</translation>
+    </message>
 </context>
 <context>
     <name>NewFolder</name>
@@ -564,6 +598,16 @@
         <source>Sort</source>
         <translation>Trier</translation>
     </message>
+    <message>
+        <location filename="../sort.cpp" line="10"/>
+        <source>Ascending</source>
+        <translation>Ascendant</translation>
+    </message>
+    <message>
+        <location filename="../sort.cpp" line="10"/>
+        <source>Descending</source>
+        <translation>Descendant</translation>
+    </message>
     <message>
         <location filename="../sort.cpp" line="10"/>
         <source>Name (A-Z)</source>
@@ -704,7 +748,7 @@
     <message>
         <location filename="../compress.cpp" line="10"/>
         <source>Adding %1...</source>
-        <translation>Ajout de 1% ...</translation>
+        <translation>Ajout de %1...</translation>
     </message>
     <message>
         <location filename="../compress.cpp" line="10"/>
@@ -783,7 +827,7 @@
     <message>
         <location filename="../extract.cpp" line="10"/>
         <source>Extracting %1...</source>
-        <translation>xtraction de %1...</translation>
+        <translation>Extraction de %1...</translation>
     </message>
     <message>
         <location filename="../extract.cpp" line="10"/>
